package net.pocketmagic.android.AndroidContactsSelector;

import android.app.Activity;
import android.database.Cursor;
import android.graphics.Color;
import android.net.Uri;
import android.os.Bundle;
import android.provider.ContactsContract;
import android.text.Editable;
import android.text.TextWatcher;
import android.util.Log;
import android.view.Gravity;
import android.view.Menu;
import android.view.View;
import android.view.Window;
import android.view.View.OnClickListener;
import android.view.ViewGroup.LayoutParams;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.Button;
import android.widget.EditText;
import android.widget.FilterQueryProvider;
import android.widget.LinearLayout;
import android.widget.ListView;
import android.widget.RelativeLayout;
import android.widget.ScrollView;
import android.widget.SimpleCursorAdapter;
import android.widget.TextView;
import android.widget.Toast;

public class AndroidContactsSelector extends Activity implements OnClickListener, TextWatcher,OnItemClickListener {
	final String 			LOG_TAG			= "PocketMagic";
	final int				idTopLayout		= Menu.FIRST + 1,
							idCancel		= Menu.FIRST + 2,
							idBotLayout		= Menu.FIRST + 3;
	
	EditText				m_etSearch;
	ListView				m_lvContacts;
	
	Cursor								m_curContacts;
	SimpleCursorAdapter 				m_slvAdapter;

	
    /** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        Log.d(LOG_TAG, "onCreate called.");
		// Setup window
		requestWindowFeature(Window.FEATURE_NO_TITLE);
		// Create interface
		RelativeLayout global_panel = new RelativeLayout (this);
		global_panel.setLayoutParams(new LayoutParams(LayoutParams.FILL_PARENT, LayoutParams.FILL_PARENT));
		global_panel.setBackgroundColor(Color.rgb(30,30,130));
		global_panel.setGravity(Gravity.FILL);
		// +++++++++++++ TOP COMPONENT
		// --- PART1: create the top menu in m_panel
		RelativeLayout ibMenu = new RelativeLayout(this);
     	ibMenu.setId(idTopLayout);
		ibMenu.setBackgroundDrawable(getResources().getDrawable(R.drawable.line));
     	int ibMenuPadding = 6;
     	ibMenu.setPadding(ibMenuPadding,ibMenuPadding,ibMenuPadding,ibMenuPadding);
     	RelativeLayout.LayoutParams topParams = new RelativeLayout.LayoutParams(LayoutParams.FILL_PARENT, LayoutParams.WRAP_CONTENT);
     	topParams.addRule(RelativeLayout.ALIGN_PARENT_TOP);
     	global_panel.addView(ibMenu,topParams);
     	// textview in ibMenu : New Contact / Merge contact
		TextView cTV = new TextView(this);
		cTV.setText("Select Contact");
		cTV.setTextColor(Color.rgb(255,255,255));
//		cTV.setId(idiLabel6);
		int nTextH =  18;
		cTV.setTextSize(nTextH);
		RelativeLayout.LayoutParams lpcTV = new RelativeLayout.LayoutParams(LayoutParams.WRAP_CONTENT, LayoutParams.WRAP_CONTENT);
		lpcTV.addRule(RelativeLayout.CENTER_IN_PARENT);
		ibMenu.addView(cTV, lpcTV);
		// cancel button in ibMenu, with .xml for two press states
		Button m_bCancel = new Button(this);
		m_bCancel.setId(idCancel);
		m_bCancel.setOnClickListener((OnClickListener) this);
		m_bCancel.setText("Exit");
		nTextH =  12;
		m_bCancel.setTextSize(nTextH);
		RelativeLayout.LayoutParams lpbCancel = new RelativeLayout.LayoutParams(LayoutParams.WRAP_CONTENT, LayoutParams.WRAP_CONTENT);
		lpbCancel.addRule(RelativeLayout.ALIGN_PARENT_LEFT);
		lpbCancel.addRule(RelativeLayout.CENTER_VERTICAL);
		ibMenu.addView(m_bCancel, lpbCancel);
		
		
		// +++++++++++++ BOTTOM COMPONENT
		RelativeLayout ibMenuBot = new RelativeLayout(this);
		ibMenuBot.setId(idBotLayout);
		ibMenuBot.setBackgroundDrawable(getResources().getDrawable(R.drawable.line));
		ibMenuBot.setPadding(ibMenuPadding,ibMenuPadding,ibMenuPadding,ibMenuPadding);
		RelativeLayout.LayoutParams botParams = new RelativeLayout.LayoutParams(LayoutParams.FILL_PARENT, LayoutParams.WRAP_CONTENT);
		botParams.addRule(RelativeLayout.ALIGN_PARENT_BOTTOM);
		global_panel.addView(ibMenuBot,botParams);
     	// Search
		m_etSearch = new EditText(this);
		m_etSearch.setHint("Search");
		//m_etSearch.setId(idSearchEdit);
		m_etSearch.addTextChangedListener((TextWatcher) this);
		RelativeLayout.LayoutParams layoutparams = new RelativeLayout.LayoutParams(LayoutParams.FILL_PARENT, LayoutParams.WRAP_CONTENT);
		layoutparams.leftMargin = 0;
		layoutparams.topMargin = 0;
		ibMenuBot.addView(m_etSearch, layoutparams);
		
		// +++++++++++++ MIDDLE COMPONENT
		LinearLayout midLayout = new LinearLayout (this);
		midLayout.setLayoutParams(new LayoutParams(LayoutParams.FILL_PARENT,LayoutParams.WRAP_CONTENT));
		midLayout.setOrientation(LinearLayout.VERTICAL);
		RelativeLayout.LayoutParams midParams = new RelativeLayout.LayoutParams(LayoutParams.FILL_PARENT, LayoutParams.WRAP_CONTENT);
		midParams.addRule(RelativeLayout.ABOVE,ibMenuBot.getId());
		midParams.addRule(RelativeLayout.BELOW,ibMenu.getId());
		global_panel.addView(midLayout,midParams );
		
		// create listview
		m_lvContacts = new ListView(this);
		m_lvContacts.setOnItemClickListener((OnItemClickListener) this);
		// Add listview to current panel
		midLayout.addView(m_lvContacts);
     	
		ReadContacts("");
		//return interface
		setContentView(global_panel);
        
        
    }
    
    void ReadContacts(String sort) {
		final Uri uri = ContactsContract.Contacts.CONTENT_URI;
        final String[] projection = new String[] {
                ContactsContract.Contacts._ID,
                ContactsContract.Contacts.DISPLAY_NAME
        };
        //boolean mShowInvisible = false;
        String selection = ContactsContract.Contacts.IN_VISIBLE_GROUP + " = '1'";
        String[] selectionArgs = null;
        final String sortOrder = ContactsContract.Contacts.DISPLAY_NAME + " COLLATE LOCALIZED ASC";

        m_curContacts = managedQuery(uri, projection, selection, selectionArgs, sortOrder);
        String[] fields = new String[] {ContactsContract.Data.DISPLAY_NAME};
        m_slvAdapter = new SimpleCursorAdapter(this, 
        		android.R.layout.simple_list_item_1, 
        		m_curContacts,
                fields, 
                new int[] {android.R.id.text1});
        m_slvAdapter.setFilterQueryProvider(new FilterQueryProvider() {
     
			public Cursor runQuery(CharSequence constraint) {
				Log.d(LOG_TAG, "runQuery constraint:"+constraint);
				String selection = ContactsContract.Contacts.IN_VISIBLE_GROUP + " = '1'" +
					" AND "+ ContactsContract.Contacts.DISPLAY_NAME + " LIKE '%"+constraint+"%'";
				String[] selectionArgs = null;//new String[]{"'1'"};//, };
				Cursor cur = managedQuery(uri, projection, selection, selectionArgs, sortOrder);
				return cur;
			}
        
        });
        m_lvContacts.setAdapter(m_slvAdapter); 
      //  cur.close();
		 
	}

    public void onDestroy() {
        super.onDestroy();
        Log.d(LOG_TAG, "onDestroy called.");
        if (m_curContacts!=null) m_curContacts.close();
        m_etSearch.removeTextChangedListener(this);

	}

	public void onClick(View v) {
		// TODO Auto-generated method stub
		if (v.getId() == idCancel) finish();	
	}
	
	public void onItemClick(AdapterView<?> arg0, View v, int position, long id) {
		Cursor cursor = (Cursor) m_lvContacts.getItemAtPosition(position);
		String szDisplayName = cursor.getString(cursor.getColumnIndexOrThrow( ContactsContract.Contacts.DISPLAY_NAME));
		String szId = cursor.getString(cursor.getColumnIndexOrThrow( ContactsContract.Contacts._ID));
		int nId = cursor.getInt(cursor.getColumnIndexOrThrow( ContactsContract.Contacts._ID));
		
		Log.d(LOG_TAG, "Item click:"+position+" szId:"+szId+" nId:"+nId+" Data:"+szDisplayName);
		Toast.makeText(getBaseContext(), "Item click:"+position+" szId:"+szId+" nId:"+nId+" Data:"+szDisplayName, Toast.LENGTH_SHORT).show();

	}
	public void afterTextChanged(Editable s) {
		// TODO Auto-generated method stub
		
	}
	public void beforeTextChanged(CharSequence s, int start, int count,
			int after) {
		// TODO Auto-generated method stub
		
	}
	public void onTextChanged(CharSequence s, int start, int before, int count) {
		// TODO Auto-generated method stub
		if (m_slvAdapter!=null) {
			m_slvAdapter.getFilter().filter(s);
			m_lvContacts.setAdapter(m_slvAdapter); 
		}

	}
}